==> haskell-unbounded-delays-0.1.1.1-7-x86_64.pkg.tar.zst: usr/share/haskell/register/haskell-unbounded-delays.sh <==
#!/bin/sh
export PATH='/usr/local/sbin:/usr/local/bin:/usr/bin:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl'
echo 'name:                 unbounded-delays
version:              0.1.1.1
visibility:           public
id:                   unbounded-delays-0.1.1.1-HyB7dbKDYek99idPmc4TXa
key:                  unbounded-delays-0.1.1.1-HyB7dbKDYek99idPmc4TXa
license:              BSD-3-Clause
copyright:            2011-2020 Bas van Dijk & Roel van Dijk
maintainer:
    Bas van Dijk <v.dijk.bas@gmail.com>
    Roel van Dijk <roel@lambdacube.nl>

author:
    Bas van Dijk <v.dijk.bas@gmail.com>
    Roel van Dijk <roel@lambdacube.nl>

homepage:             https://github.com/basvandijk/unbounded-delays
synopsis:             Unbounded thread delays and timeouts
description:
    The @threadDelay@ and @timeout@ functions from the @base@ library
    use the bounded @Int@ type for specifying the delay or timeout
    period. This packages provides alternatives which use the
    unbounded @Integer@ type.

category:             Concurrency
abi:                  65ddadcb003bc2376ee8e20183189d81
exposed:              True
exposed-modules:
    Control.Concurrent.Thread.Delay Control.Concurrent.Timeout

import-dirs:          /usr/lib/ghc-9.2.8/site-local/unbounded-delays-0.1.1.1
library-dirs:         /usr/lib/ghc-9.2.8/site-local/unbounded-delays-0.1.1.1
dynamic-library-dirs: /usr/lib
data-dir:             /usr/share/haskell-unbounded-delays
hs-libraries:         HSunbounded-delays-0.1.1.1-HyB7dbKDYek99idPmc4TXa
depends:              base-4.16.4.0
haddock-interfaces:
    /usr/share/doc/haskell-unbounded-delays/html/unbounded-delays.haddock

haddock-html:         /usr/share/doc/haskell-unbounded-delays/html
' | '/usr/bin/ghc-pkg-9.2.8' 'update' '--force' '-' '--global' '--no-user-package-db' "$@"

==> haskell-unbounded-delays-0.1.1.1-8-x86_64.pkg.tar.zst: usr/share/haskell/register/haskell-unbounded-delays.sh <==
#!/bin/sh
export PATH='/usr/local/sbin:/usr/local/bin:/usr/bin:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl'
printf '%s' 'name:                 unbounded-delays
version:              0.1.1.1
visibility:           public
id:                   unbounded-delays-0.1.1.1-9PQJht8VjI9BW2tiXlJWhX
key:                  unbounded-delays-0.1.1.1-9PQJht8VjI9BW2tiXlJWhX
license:              BSD-3-Clause
copyright:            2011-2020 Bas van Dijk & Roel van Dijk
maintainer:
    Bas van Dijk <v.dijk.bas@gmail.com>
    Roel van Dijk <roel@lambdacube.nl>

author:
    Bas van Dijk <v.dijk.bas@gmail.com>
    Roel van Dijk <roel@lambdacube.nl>

homepage:             https://github.com/basvandijk/unbounded-delays
synopsis:             Unbounded thread delays and timeouts
description:
    The @threadDelay@ and @timeout@ functions from the @base@ library
    use the bounded @Int@ type for specifying the delay or timeout
    period. This packages provides alternatives which use the
    unbounded @Integer@ type.

category:             Concurrency
abi:                  e85b5bd7c04232ffd433d6f45439f811
exposed:              True
exposed-modules:
    Control.Concurrent.Thread.Delay Control.Concurrent.Timeout

import-dirs:          /usr/lib/ghc-9.4.8/site-local/unbounded-delays-0.1.1.1
library-dirs:         /usr/lib/ghc-9.4.8/site-local/unbounded-delays-0.1.1.1
library-dirs-static:  /usr/lib/ghc-9.4.8/site-local/unbounded-delays-0.1.1.1
dynamic-library-dirs: /usr/lib
data-dir:             /usr/share/haskell-unbounded-delays
hs-libraries:         HSunbounded-delays-0.1.1.1-9PQJht8VjI9BW2tiXlJWhX
depends:              base-4.17.2.1
haddock-interfaces:
    /usr/share/doc/haskell-unbounded-delays/html/unbounded-delays.haddock

haddock-html:         /usr/share/doc/haskell-unbounded-delays/html
' | '/usr/bin/ghc-pkg-9.4.8' 'update' '--force' '-' '--global' '--no-user-package-db' "$@"
